summaryrefslogtreecommitdiff
path: root/reportdesign
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2012-07-30 08:41:34 +0200
committerStephan Bergmann <sbergman@redhat.com>2012-07-30 09:26:00 +0200
commit889de665ec9d2ac25a9dccd4830cb97ed0c7c56e (patch)
treef98ed6e8215a39287248189841411e0edb0439c3 /reportdesign
parent291dcae246de9e32d9ca5926be463ad910c5bd1e (diff)
Typo ressource -> resource
Change-Id: Id13e7acfbe34eca5e124c9032d36d6f158bfb831
Diffstat (limited to 'reportdesign')
-rw-r--r--reportdesign/inc/ModuleHelper.hxx4
-rw-r--r--reportdesign/source/core/inc/core_resource.hxx2
-rw-r--r--reportdesign/source/core/sdr/ModuleHelper.cxx16
3 files changed, 11 insertions, 11 deletions
diff --git a/reportdesign/inc/ModuleHelper.hxx b/reportdesign/inc/ModuleHelper.hxx
index ad1cb6761256..297216ed4af7 100644
--- a/reportdesign/inc/ModuleHelper.hxx
+++ b/reportdesign/inc/ModuleHelper.hxx
@@ -72,7 +72,7 @@ namespace rptui
//=========================================================================
//= OModuleClient
//=========================================================================
- /** base class for objects which uses any global module-specific ressources
+ /** base class for objects which uses any global module-specific resources
*/
class REPORTDESIGN_DLLPUBLIC OModuleClient
{
@@ -84,7 +84,7 @@ namespace rptui
//=========================================================================
//= ModuleRes
//=========================================================================
- /** specialized ResId, using the ressource manager provided by the global module
+ /** specialized ResId, using the resource manager provided by the global module
*/
class REPORTDESIGN_DLLPUBLIC ModuleRes : public ::ResId
{
diff --git a/reportdesign/source/core/inc/core_resource.hxx b/reportdesign/source/core/inc/core_resource.hxx
index 078ae049bf0f..468cabb9fea3 100644
--- a/reportdesign/source/core/inc/core_resource.hxx
+++ b/reportdesign/source/core/inc/core_resource.hxx
@@ -32,7 +32,7 @@ namespace reportdesign
//==================================================================
//= ResourceManager
- //= handling ressources within the DBA-Core library
+ //= handling resources within the DBA-Core library
//==================================================================
class ResourceManager
{
diff --git a/reportdesign/source/core/sdr/ModuleHelper.cxx b/reportdesign/source/core/sdr/ModuleHelper.cxx
index 58a286080f2d..f6f6071765ef 100644
--- a/reportdesign/source/core/sdr/ModuleHelper.cxx
+++ b/reportdesign/source/core/sdr/ModuleHelper.cxx
@@ -54,21 +54,21 @@ namespace rptui
*/
class OModuleImpl
{
- ResMgr* m_pRessources;
+ ResMgr* m_pResources;
public:
/// ctor
OModuleImpl();
~OModuleImpl();
/// get the manager for the ressources of the module
ResMgr* getResManager();
};
DBG_NAME( rpt_OModuleImpl )
//-------------------------------------------------------------------------
OModuleImpl::OModuleImpl()
- :m_pRessources(NULL)
+ :m_pResources(NULL)
{
DBG_CTOR( rpt_OModuleImpl,NULL);
@@ -77,8 +77,8 @@ OModuleImpl::OModuleImpl()
//-------------------------------------------------------------------------
OModuleImpl::~OModuleImpl()
{
- if (m_pRessources)
- delete m_pRessources;
+ if (m_pResources)
+ delete m_pResources;
DBG_DTOR( rpt_OModuleImpl,NULL);
}
@@ -88,12 +88,12 @@ ResMgr* OModuleImpl::getResManager()
{
// note that this method is not threadsafe, which counts for the whole class !
- if (!m_pRessources)
+ if (!m_pResources)
{
// create a manager with a fixed prefix
- m_pRessources = ResMgr::CreateResMgr("rptui");
+ m_pResources = ResMgr::CreateResMgr("rptui");
}
- return m_pRessources;
+ return m_pResources;
}
//=========================================================================
@@ -54,21 +54,21 @@ namespace rptui
OModuleImpl();
~OModuleImpl();
- /// get the manager for the ressources of the module
+ /// get the manager for the resources of the module
ResMgr* getResManager();
};